@@ -1,5 +1,5 @@
 slug <- paste("test-gs", Sys.info()["user"], "", sep = "-")
 
-TEST <- tempfile(slug, tmpdir = "") %>% basename
+TEST <- tempfile(slug, tmpdir = "") %>% basename()
 
 p_ <- function(x) paste(TEST, x, sep = "-")
